# Copyright (C) 2005 Grahame Bowland <grahame@angrygoats.net>
#
# This program is made available under the GNU GPL version 2.0 or
# greater. See the accompanying file COPYING for details.
#
# This program is distributed WITHOUT ANY WARRANTY; without even the
# implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE.

#
# config.py
#
# This python script is imported by ViewMTN
# Note that changes to the script may not be 
# noticed immediately by ViewMTN, as mod_python 
# caches imported Python modules.
#
# If config changes are not picked up, reloading
# the web server should solve the issue.
#

import sys

# default addresses should work without modification
# if running viewmtn standalone. You must change these 
# if you run viewmtn with a web server, see INSTALL.
dynamic_uri_path = '/viewmtn/'
static_uri_path = '/viewmtn-static/'

# Directory in which to find the templates/ files.
# Depending on the web server setup, this might need to be absolute.
templates_directory = '/usr/share/viewmtn/templates/'

# if you are running under Apache2, set this.
# don't set it otherwise, it breaks any other configuration 
# including running standalone.
running_under_apache2 = False # not relevant to mod_wsgi setup

# the path to the 'mtn' binary
monotone = '/usr/bin/mtn'

#
# Database files:
# You can do this two ways.
# ( 1) Define "dbfile" as follows. VieWMTN will only
#      allow access to one database.
# (2a) Define "dbfiles". This tuple will describe several 
#      databases which ViewMTN will allow users to access.
#      The format is as ( name , path, description, ... )
#      - just follow the patten in the example.
#      The default database is defined via "defaultdb".
# (2b) Define "dbfiles" as a function taking no arguments, 
#      and returning a tuple in the format specified under 
#      (2a). dbfiles must be a function, not just code, to 
#      avoid running a scan every time the config.py module 
#      is imported.
#
# If you have defined "dbfiles", it takes precedence over 
# "dbfile". 
#
# Everything in the databases you export should be considered 
# subject to disclosure. Don't store your private key in 
# any of the databases you export!
#

# Style (1)
# dbfile = '/path/to/my/viewmtn.db'

# Style (2a)
# dbfiles = ("database1", "/path/to/stuff.db", "my stuff", 
#            "database2", "/path/to/junk.db", "my other stuff")
# defaultdb = "database1"

# Style (2b)
# WARNING: this will publish _all_ the databases in the directory 
# matched by the call to glob, if they have a corresponding .descr 
# file. Check this is really what you mean to do!
#
# import os,glob
# dbfiles = lambda: reduce (lambda a, b: a+b, 
#                           [ (os.path.basename(t).split('.',1)[0], 
#                              t, 
#                              open(t+'.descr').read().strip()
#                             ) for t in glob.glob("/Users/grahame/mtn/db/*.db")
#                             if os.access(t+'.descr', os.R_OK)])

# highlight from http://andre-simon.de/
# if you don't have this available, just comment 
# the "highlight_command" line out
highlight_command = '/usr/bin/highlight'

graphopts = {
    # a directory (must be writable by the web user)
    # in which viewmtn can output graph files
    # (you should set up a cronjob to delete old ones
    #  periodically)
    'directory' : '/var/cache/viewmtn-graph/',

    # a URL, relative or absolute, at which the files 
    # in the 'graphdir' directory can be found. Should 
    # end in a '/' character
    'uri' : 'graph/',

    # the path to the 'dot' program
    'dot' : '/usr/bin/dot',

    # options to use for nodes in the dot input file
    # we generate. Note that the font below (Monaco) 
    # might not be present on your system; try something 
    # like "Luxi mono" should look nice
    'nodeopts' : { 'fontname'  : 'Monaco', 
       'fontsize'  : '8',
       'shape'     : 'box',
       'height'    : '0.3',
       'spline'    : 'true',
       'style'     : 'filled',
       'fillcolor' : '#dddddd' }
}

# Icon Theme to use for icons; 'gnome' is a safe value, 
# as is 'hicolor'. Note that icon_size must be a string, 
# not an integer
# Set icon_theme = None to disable icons.
icon_theme = 'gnome'
icon_size = '16'

# Some installations may have shared MIME info that is 
# unhelpful. Forced remappings can be placed in the 
# following hash table (uncomment it to enable it)
#
# mime_map = { 'application/x-python' : 'text/plain' }
#

# Get the local configuration linked from %{_sysconfdir}/.
from user_config import *
